@@ -3,6 +3,7 @@
 #Could make bounce effect when hit boundaries by sending in opposite direction for count down moment
 #could make accelrate faster by using previuos x,y as well as start x,y as startx,y means you cant accelerate until back to starting point.
 
+#13.05.10    Fixed all paths to point to opt/snapy instead of opt root
 #               Increase speed per level
 #               Reset acceleration at start each level
 #               Added 'p' to pause feature
@@ -281,7 +282,7 @@ def  debug_me():
         global right,  up,  x,  y,  accel_x,  accel_y, speed, death_detail, death_history
         map_me(x, y, "#")
         print "writing map to disk..."
-        file = open("/home/opt/map.txt" , 'w')
+        file = open("/home/opt/snapy/map.txt" , 'w')
         count = 0
         while count <> screen_y -1:
             file.write(map[count] + "\n") 
@@ -297,7 +298,7 @@ def  debug_me():
 def  write_file():
     try:
         global debug_line
-        file = open("/home/opt/debug.txt" , 'w')
+        file = open("/home/opt/snapy/debug.txt" , 'w')
         file.write("Debug: " + debug_line)
         file.close() 
     except:
@@ -346,7 +347,7 @@ def save_game_settings():
         if position <> 0:
             #Just saves high score
             print "writing game data to disk..."
-            file = open("/home/opt/snapy.dat" , 'w')
+            file = open("/home/opt/snapy/snapy.dat" , 'w')
             file.write("HighScore1: " + str(high_score) + "\n")
             file.write("HighScore2: " + str(high_score2) + "\n")
             file.write("HighScore3: " + str(high_score3) + "\n")
@@ -368,7 +369,7 @@ def load_game_settings():
     #Just saves high score
     print "reading game data from disk..."
     try:
-        file = open("/home/opt/snapy.dat" , 'r')  #open("/home/opt/snapy.dat" , 'r')
+        file = open("/home/opt/snapy/snapy.dat" , 'r')  #open("/home/opt/snapy.dat" , 'r')
     except:
         save_game_settings()
         return
@@ -420,7 +421,7 @@ def pet_name():
     screen.fill(black)
     pygame.display.flip()
     
-    sound = mixer.Sound("/home/opt/sfx/highscore.wav")
+    sound = mixer.Sound("/home/opt/snapy/sfx/highscore.wav")
     #start playing
     channel = sound.play()
     
@@ -649,7 +650,7 @@ def death_march():
     blueup = 1
     
     if new_high_score == 1:
-        sound = mixer.Sound("/home/opt/sfx/gooseter.wav")
+        sound = mixer.Sound("/home/opt/snapy/sfx/gooseter.wav")
         #start playing
         channel = sound.play()
     
@@ -671,7 +672,7 @@ def death_march():
         
         if new_high_score == 1:
             if not channel.get_busy():
-                sound = mixer.Sound("/home/opt/sfx/gooseter.wav")
+                sound = mixer.Sound("/home/opt/snapy/sfx/gooseter.wav")
                 #start playing
                 channel = sound.play()
                 
@@ -727,7 +728,7 @@ def eat_or_die():
         toys = 0
         vibrate_small()
         #sfx_rnd = random.randint(1, 5)
-        sfx_file = "/home/opt/sfx/toy.wav"
+        sfx_file = "/home/opt/snapy/sfx/toy.wav"
         print sfx_file
         sound = mixer.Sound(sfx_file)
         #start playing
@@ -799,7 +800,7 @@ def eat_or_die():
             pygame.display.flip()
             vibes()
             #load the sound    
-            sound = mixer.Sound("/home/opt/sfx/hit.wav")
+            sound = mixer.Sound("/home/opt/snapy/sfx/hit.wav")
             #start playing
             channel = sound.play()
             #Save high score
@@ -818,7 +819,7 @@ def eat_or_die():
             #Play eat sfx
             #load the sound 
             sfx_rnd = random.randint(1, 5)
-            sfx_file = "/home/opt/sfx/hiss"+ str(sfx_rnd) + ".wav"
+            sfx_file = "/home/opt/snapy/sfx/hiss"+ str(sfx_rnd) + ".wav"
             print sfx_file
             sound = mixer.Sound(sfx_file)
             #start playing
@@ -827,7 +828,7 @@ def eat_or_die():
             if not bg_channel.get_busy():
                 if sfx_rnd == 1:
                     sfx_rnd = random.randint(1, 3)
-                    sfx_file = "/home/opt/sfx/jungle"+ str(sfx_rnd) + ".wav"
+                    sfx_file = "/home/opt/snapy/sfx/jungle"+ str(sfx_rnd) + ".wav"
                     print sfx_file
                     sound = mixer.Sound(sfx_file)
                     #start playing
@@ -871,7 +872,7 @@ def eat_or_die():
         food_x = random.randint(0, screen_x-32)
         food_y = random.randint(0, screen_y-32)
         rnd_no = random.randint(1, 4)
-        food = pygame.image.load("/home/opt/images/food" + str(rnd_no) + ".jpg").convert()
+        food = pygame.image.load("/home/opt/snapy/images/food" + str(rnd_no) + ".jpg").convert()
         screen.blit(food, (food_x,food_y))
         if speed > (.25 * 8):
             if rnd_no < 2:
@@ -879,9 +880,9 @@ def eat_or_die():
                 toys = 1
                 toy_x = random.randint(0, screen_x-32)
                 toy_y = random.randint(0, screen_y-32)
-                toy = pygame.image.load("/home/opt/images/toy.jpg").convert()
+                toy = pygame.image.load("/home/opt/snapy/images/toy.jpg").convert()
                 screen.blit(toy, (toy_x,toy_y))
-                sfx_file = "/home/opt/sfx/rattle.wav"
+                sfx_file = "/home/opt/snapy/sfx/rattle.wav"
                 print sfx_file
                 sound = mixer.Sound(sfx_file)
                 #start playing
@@ -923,13 +924,13 @@ screen.fill(black)
 pygame.mouse.set_visible(0)
 
 
-snapy = pygame.image.load("/home/opt/images/head.jpg").convert()
+snapy = pygame.image.load("/home/opt/snapy/images/head.jpg").convert()
 snapy.set_colorkey(black, RLEACCEL)
-immortal_snapy = pygame.image.load("/home/opt/images/immortal_head.jpg").convert()
+immortal_snapy = pygame.image.load("/home/opt/snapy/images/immortal_head.jpg").convert()
 immortal_snapy.set_colorkey(black, RLEACCEL)
-blank_snapy = pygame.image.load("/home/opt/images/blank_head.jpg").convert()
+blank_snapy = pygame.image.load("/home/opt/snapy/images/blank_head.jpg").convert()
 
-food = pygame.image.load("/home/opt/images/food" + str(random.randint(1, 4)) + ".jpg").convert()
+food = pygame.image.load("/home/opt/snapy/images/food" + str(random.randint(1, 4)) + ".jpg").convert()
 food_x = random.randint(0, screen_x-32)
 food_y = random.randint(0, screen_y-32)
 screen.blit(food, (food_x,food_y))
@@ -944,7 +945,7 @@ str_ac = get_rotation()
 pygame.display.flip()
 
 #Initial background sfx
-sound = mixer.Sound("/home/opt/sfx/jungle.wav")
+sound = mixer.Sound("/home/opt/snapy/sfx/jungle.wav")
 #start playing
 bg_channel = sound.play()
 # Initialise clock
